@@ -500,7 +500,9 @@ wxString LIB_SYMBOL::SubReference( int aUnit, bool aAddSeparator )
         subRef << wxChar( m_subpartIdSeparator );
 
     if( m_subpartFirstId >= '0' && m_subpartFirstId <= '9' )
+    {
         subRef << aUnit;
+    }
     else
     {
         // use letters as notation. To allow more than 26 units, the sub ref
@@ -932,13 +934,16 @@ const EDA_RECT LIB_SYMBOL::GetBodyBoundingBox( int aUnit, int aConvert, bool aIn
         {
             const LIB_PIN& pin = static_cast<const LIB_PIN&>( item );
 
-            // Note: the roots of the pins are always included for symbols that don't have a
-            // well-defined body.
+            if( pin.IsVisible() )
+            {
+                // Note: the roots of the pins are always included for symbols that don't have
+                // a well-defined body.
 
-            if( aIncludePins && pin.IsVisible() )
-                bbox.Merge( pin.GetBoundingBox( false, true ) );
-            else
-                bbox.Merge( pin.GetPinRoot() );
+                if( aIncludePins )
+                    bbox.Merge( pin.GetBoundingBox( false, true ) );
+                else
+                    bbox.Merge( pin.GetPinRoot() );
+            }
         }
         else
         {
