@@ -4,7 +4,7 @@
  * Copyright (C) 2015 Jean-Pierre Charras, jp.charras at wanadoo.fr
  * Copyright (C) 2014 Dick Hollenbeck, dick@softplc.com
  * Copyright (C) 2015 Wayne Stambaugh <stambaughw@gmail.com>
- * Copyright (C) 1992-2021 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 1992-2022 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -78,7 +78,7 @@ extern std::string toUTFTildaText( const wxString& txt );
 class SCH_SYMBOL : public SCH_ITEM
 {
 public:
-    SCH_SYMBOL( const wxPoint& pos = wxPoint( 0, 0 ), SCH_ITEM* aParent = nullptr );
+    SCH_SYMBOL( const wxPoint& aPosition = wxPoint( 0, 0 ), EDA_ITEM* aParent = nullptr );
 
     /**
      * Create schematic symbol from library symbol object.
@@ -86,16 +86,16 @@ public:
      * @param aSymbol is the library symbol to create schematic symbol from.
      * @param aLibId is the #LIB_ID of alias to create.
      * @param aSheet is the schematic sheet the symbol is place into.
-     * @param unit is unit for symbols that have multiple parts per package.
-     * @param convert is the alternate body style for the schematic symbols.
-     * @param pos is the position of the symbol.
-     * @param setNewItemFlag is used to set the symbol #IS_NEW and #IS_MOVING flags.
+     * @param aUnit is unit for symbols that have multiple parts per package.
+     * @param aConvert is the alternate body style for the schematic symbols.
+     * @param aPositions is the position of the symbol.
      */
     SCH_SYMBOL( const LIB_SYMBOL& aSymbol, const LIB_ID& aLibId, const SCH_SHEET_PATH* aSheet,
-                int unit, int convert = 0, const wxPoint& pos = wxPoint( 0, 0 ) );
+                int aUnit, int aConvert = 0, const wxPoint& aPosition = wxPoint( 0, 0 ),
+                EDA_ITEM* aParent = nullptr );
 
     SCH_SYMBOL( const LIB_SYMBOL& aSymbol, const SCH_SHEET_PATH* aSheet, const PICKED_SYMBOL& aSel,
-                const wxPoint& pos = wxPoint( 0, 0 ) );
+                const wxPoint& aPosition = wxPoint( 0, 0 ), EDA_ITEM* aParent = nullptr );
 
     /**
      * Clone \a aSymbol into a new schematic symbol object.
@@ -120,6 +120,21 @@ public:
         return wxT( "SCH_SYMBOL" );
     }
 
+    /**
+     * Check to see if the library symbol is set to the dummy library symbol.
+     *
+     * When the library symbol is missing (which technically should not happen now that the
+     * library symbols are cached in the schematic file), a dummy library symbol is substituted
+     * for the missing symbol as an indicator that something is amiss.  The dummy symbol cannot
+     * be edited so a check for this symbol must be performed before attempting to edit the
+     * library symbol with the library editor or it will crash KiCad.
+     *
+     * @see dummy()
+     *
+     * @return true if the library symbol is missing or false if it is valid.
+     */
+    bool IsMissingLibSymbol() const;
+
     const std::vector<SYMBOL_INSTANCE_REFERENCE>& GetInstanceReferences()
     {
         return m_instanceReferences;
@@ -650,6 +665,14 @@ public:
 
     void Plot( PLOTTER* aPlotter ) const override;
 
+    /**
+     * Plot just the symbol pins.  This is separated to match the GAL display order.  The pins are
+     * ALSO plotted with the symbol group.  This replotting allows us to ensure that they are shown above
+     * other elements in the schematic
+     * @param aPlotter
+     */
+    void PlotPins( PLOTTER* aPlotter ) const;
+
     EDA_ITEM* Clone() const override;
 
 #if defined(DEBUG)
