@@ -717,7 +717,7 @@ void DRC_ENGINE::RunTests( EDA_UNITS aUnits, bool aReportAllTrackErrors, bool aT
                 copperZones.push_back( zone );
         }
 
-        footprint->BuildPolyCourtyards();
+        footprint->BuildCourtyardCaches();
     }
 
     int zoneCount = copperZones.size();
@@ -782,11 +782,19 @@ DRC_CONSTRAINT DRC_ENGINE::EvalRules( DRC_CONSTRAINT_T aConstraintType, const BO
     // Local overrides take precedence over everything *except* board min clearance
     if( aConstraintType == CLEARANCE_CONSTRAINT || aConstraintType == HOLE_CLEARANCE_CONSTRAINT )
     {
-        int override = 0;
+        int override_val = 0;
+        int overrideA = 0;
+        int overrideB = 0;
 
         if( ac && !b_is_non_copper )
+            overrideA = ac->GetLocalClearanceOverrides( nullptr );
+
+        if( bc && !a_is_non_copper )
+            overrideB = bc->GetLocalClearanceOverrides( nullptr );
+
+        if( overrideA > 0 || overrideB > 0 )
         {
-            int overrideA = ac->GetLocalClearanceOverrides( nullptr );
+            wxString msg;
 
             if( overrideA > 0 )
             {
@@ -795,13 +803,8 @@ DRC_CONSTRAINT DRC_ENGINE::EvalRules( DRC_CONSTRAINT_T aConstraintType, const BO
                                           EscapeHTML( a->GetSelectMenuText( UNITS ) ),
                                           REPORT_VALUE( overrideA ) ) )
 
-                override = ac->GetLocalClearanceOverrides( &m_msg );
+                override_val = ac->GetLocalClearanceOverrides( &msg );
             }
-        }
-
-        if( bc && !a_is_non_copper )
-        {
-            int overrideB = bc->GetLocalClearanceOverrides( nullptr );
 
             if( overrideB > 0 )
             {
@@ -810,41 +813,41 @@ DRC_CONSTRAINT DRC_ENGINE::EvalRules( DRC_CONSTRAINT_T aConstraintType, const BO
                                           EscapeHTML( b->GetSelectMenuText( UNITS ) ),
                                           EscapeHTML( REPORT_VALUE( overrideB ) ) ) )
 
-                if( overrideB > override )
-                    override = bc->GetLocalClearanceOverrides( &m_msg );
+                if( overrideB > override_val )
+                    override_val = bc->GetLocalClearanceOverrides( &msg );
             }
-        }
 
-        if( override )
-        {
-            if( aConstraintType == CLEARANCE_CONSTRAINT )
+            if( override_val )
             {
-                if( override < m_designSettings->m_MinClearance )
+                if( aConstraintType == CLEARANCE_CONSTRAINT )
                 {
-                    override = m_designSettings->m_MinClearance;
-                    m_msg = _( "board minimum" );
+                    if( override_val < m_designSettings->m_MinClearance )
+                    {
+                        override_val = m_designSettings->m_MinClearance;
+                        msg = _( "board minimum" );
 
-                    REPORT( "" )
-                    REPORT( wxString::Format( _( "Board minimum clearance: %s." ),
-                                              REPORT_VALUE( override ) ) )
+                        REPORT( "" )
+                        REPORT( wxString::Format( _( "Board minimum clearance: %s." ),
+                                                  REPORT_VALUE( override_val ) ) )
+                    }
                 }
-            }
-            else
-            {
-                if( override < m_designSettings->m_HoleClearance )
+                else
                 {
-                    override = m_designSettings->m_HoleClearance;
-                    m_msg = _( "board minimum hole" );
+                    if( override_val < m_designSettings->m_HoleClearance )
+                    {
+                        override_val = m_designSettings->m_HoleClearance;
+                        msg = _( "board minimum hole" );
 
-                    REPORT( "" )
-                    REPORT( wxString::Format( _( "Board minimum hole clearance: %s." ),
-                                              REPORT_VALUE( override ) ) )
+                        REPORT( "" )
+                        REPORT( wxString::Format( _( "Board minimum hole clearance: %s." ),
+                                                  REPORT_VALUE( override_val ) ) )
+                    }
                 }
-            }
 
-            constraint.SetName( m_msg );
-            constraint.m_Value.SetMin( override );
-            return constraint;
+                constraint.SetName( msg );
+                constraint.m_Value.SetMin( override_val );
+                return constraint;
+            }
         }
     }
 
@@ -879,10 +882,10 @@ DRC_CONSTRAINT DRC_ENGINE::EvalRules( DRC_CONSTRAINT_T aConstraintType, const BO
                         wxString min = wxT( "<i>" ) + _( "undefined" ) + wxT( "</i>" );
                         wxString opt = wxT( "<i>" ) + _( "undefined" ) + wxT( "</i>" );
                         wxString max = wxT( "<i>" ) + _( "undefined" ) + wxT( "</i>" );
-                        wxString msg;
 
                         if( implicit )
                         {
+                            wxString msg;
                             opt = StringFromValue( UNITS, c->constraint.m_Value.Opt(), true );
 
                             switch( c->constraint.m_Type )
@@ -987,10 +990,10 @@ DRC_CONSTRAINT DRC_ENGINE::EvalRules( DRC_CONSTRAINT_T aConstraintType, const BO
                     {
                         const FOOTPRINT* footprint = static_cast<const FOOTPRINT*>( a );
 
-                        if( !footprint->GetPolyCourtyard( F_CrtYd ).IsEmpty() )
+                        if( !footprint->GetCourtyard( F_CrtYd ).IsEmpty() )
                             itemLayers |= LSET::FrontMask();
 
-                        if( !footprint->GetPolyCourtyard( B_CrtYd ).IsEmpty() )
+                        if( !footprint->GetCourtyard( B_CrtYd ).IsEmpty() )
                             itemLayers |= LSET::BackMask();
                     }
 
@@ -1108,6 +1111,7 @@ DRC_CONSTRAINT DRC_ENGINE::EvalRules( DRC_CONSTRAINT_T aConstraintType, const BO
         int localA = ac ? ac->GetLocalClearance( nullptr ) : 0;
         int localB = bc ? bc->GetLocalClearance( nullptr ) : 0;
         int clearance = global;
+        wxString msg;
 
         if( localA > 0 )
         {
@@ -1117,7 +1121,7 @@ DRC_CONSTRAINT DRC_ENGINE::EvalRules( DRC_CONSTRAINT_T aConstraintType, const BO
                                       REPORT_VALUE( localA ) ) )
 
             if( localA > clearance )
-                clearance = ac->GetLocalClearance( &m_msg );
+                clearance = ac->GetLocalClearance( &msg );
         }
 
         if( localB > 0 )
@@ -1128,13 +1132,13 @@ DRC_CONSTRAINT DRC_ENGINE::EvalRules( DRC_CONSTRAINT_T aConstraintType, const BO
                                       REPORT_VALUE( localB ) ) )
 
             if( localB > clearance )
-                clearance = bc->GetLocalClearance( &m_msg );
+                clearance = bc->GetLocalClearance( &msg );
         }
 
         if( localA > global || localB > global )
         {
             constraint.SetParentRule( nullptr );
-            constraint.SetName( m_msg );
+            constraint.SetName( msg );
             constraint.m_Value.SetMin( clearance );
             return constraint;
         }
