@@ -797,12 +797,12 @@ bool PCB_SELECTION_TOOL::selectMultiple()
          * Left > Right : Select objects that are fully enclosed by selection
          * Right > Left : Select objects that are crossed by selection
          */
-        bool windowSelection = width >= 0 ? true : false;
+        bool greedySelection = width >= 0 ? false : true;
 
         if( view->IsMirroredX() )
-            windowSelection = !windowSelection;
+            greedySelection = !greedySelection;
 
-        m_frame->GetCanvas()->SetCurrentCursor( windowSelection ? KICURSOR::SELECT_WINDOW
+        m_frame->GetCanvas()->SetCurrentCursor( !greedySelection ? KICURSOR::SELECT_WINDOW
                                                                 : KICURSOR::SELECT_LASSO );
 
         if( evt->IsCancelInteractive() || evt->IsActivate() )
@@ -853,13 +853,37 @@ bool PCB_SELECTION_TOOL::selectMultiple()
             selectionRect.Normalize();
 
             GENERAL_COLLECTOR collector;
+            std::set<BOARD_ITEM*> group_items;
+
+            for( PCB_GROUP* group : board()->Groups() )
+            {
+                // The currently entered group does not get limited
+                if( m_enteredGroup == group )
+                    continue;
+
+                std::unordered_set<BOARD_ITEM*>& newset = group->GetItems();
+
+                // If we are not greedy and have selected the whole group, add just one item
+                // to allow it to be promoted to the group later
+                if( !greedySelection && selectionRect.Contains( group->GetBoundingBox() )
+                        && newset.size() )
+                {
+                    collector.Append( *newset.begin() );
+                }
+
+                for( BOARD_ITEM* group_item : newset )
+                    group_items.emplace( group_item );
+            }
 
             for( auto it = candidates.begin(), it_end = candidates.end(); it != it_end; ++it )
             {
                 BOARD_ITEM* item = static_cast<BOARD_ITEM*>( it->first );
 
-                if( item && Selectable( item ) && item->HitTest( selectionRect, windowSelection ) )
+                if( item && Selectable( item ) && item->HitTest( selectionRect, !greedySelection )
+                        && ( greedySelection || !group_items.count( item ) ) )
+                {
                     collector.Append( item );
+                }
             }
 
             // Apply the stateful filter
@@ -1354,6 +1378,7 @@ int PCB_SELECTION_TOOL::selectNet( const TOOL_EVENT& aEvent )
 void PCB_SELECTION_TOOL::selectAllItemsOnSheet( wxString& aSheetPath )
 {
     std::list<FOOTPRINT*> footprintList;
+    bool isRootSheet = aSheetPath == wxT( "/" );
 
     // store all footprints that are on that sheet path
     for( FOOTPRINT* footprint : board()->Footprints() )
@@ -1363,11 +1388,21 @@ void PCB_SELECTION_TOOL::selectAllItemsOnSheet( wxString& aSheetPath )
 
         wxString footprint_path = footprint->GetPath().AsString().BeforeLast('/');
 
-        if( aSheetPath.IsEmpty() )
-            aSheetPath += '/';
+        if( footprint_path.IsEmpty() )
+            footprint_path += '/';
 
-        if( footprint_path.StartsWith( aSheetPath ) )
+        if( isRootSheet )
+        {
+            // We are in the root sheet, so it makes no sense to select all footprints
+            // on board. So we select only footprints leaving in the root sheet
+            if( footprint_path == aSheetPath )
+                footprintList.push_back( footprint );
+        }
+        else if( footprint_path.StartsWith( aSheetPath ) )
+        {
+            // We are in a subsheet, select all footprints in this sheet and its subsheets
             footprintList.push_back( footprint );
+        }
     }
 
     // Generate a list of all pads, and of all nets they belong to.
@@ -2546,7 +2581,7 @@ void PCB_SELECTION_TOOL::GuessSelectionCandidates( GENERAL_COLLECTOR& aCollector
     for( int i = 0; i < aCollector.GetCount(); ++i )
     {
         BOARD_ITEM* item = aCollector[i];
-        double      area;
+        double      area = 0.0;
 
         if( ( item->Type() == PCB_ZONE_T || item->Type() == PCB_FP_ZONE_T )
                 && static_cast<ZONE*>( item )->HitTestForEdge( where, MAX_SLOP * pixel / 2 ) )
@@ -2643,7 +2678,7 @@ void PCB_SELECTION_TOOL::FilterCollectorForHierarchy( GENERAL_COLLECTOR& aCollec
     std::unordered_set<BOARD_ITEM*> toAdd;
 
     // Set TEMP_SELECTED on all parents which are included in the GENERAL_COLLECTOR.  This
-    // algorithm is O3n, whereas checking for the parent inclusion could potentially be On^2.
+    // algorithm is O(3n), whereas checking for the parent inclusion could potentially be O(n^2).
     for( int j = 0; j < aCollector.GetCount(); j++ )
     {
         if( aCollector[j]->GetParent() )
